pub struct RepositorySnapshot { /* private fields */ }Expand description
A complete, immutable, structurally valid view of a knowledge-base repository.
Resources are indexed by identifiers and iterate in identifier order.
Implementations
Sourceimpl RepositorySnapshot
impl RepositorySnapshot
Sourcepub fn load(root: impl AsRef<Path>) -> Result<RepositorySnapshot, Error>
pub fn load(root: impl AsRef<Path>) -> Result<RepositorySnapshot, Error>
Loads all managed structured resources from root.
pub fn entities(&self) -> &BTreeMap<EntityId, Entity>
pub fn entity_types(&self) -> &BTreeMap<EntityTypeId, EntityType>
pub fn properties(&self) -> &BTreeMap<PropertyId, Property>
pub fn references(&self) -> &BTreeMap<ReferenceId, Reference>
pub fn allocation(&self) -> &IdAllocation